@@ -1,5 +1,8 @@
-# -*- coding: utf-8 -*-
 from .dec import DecFileParser
 from .enums import known_decay_models
 
 __all__ = ("DecFileParser", "known_decay_models")
+
+
+def __dir__():
+    return __all__
