@@ -1,5 +1,4 @@
-# -*- coding: utf-8 -*-
-# Copyright (c) 2018-2021, Eduardo Rodrigues and Henry Schreiner.
+# Copyright (c) 2018-2022, Eduardo Rodrigues and Henry Schreiner.
 #
 # Distributed under the 3-clause BSD license, see accompanying file LICENSE
 # or https://github.com/scikit-hep/decaylanguage for details.
@@ -37,20 +36,13 @@ Basic assumptions
     with another 'CopyDecay' statement.
 """
 
-from __future__ import absolute_import, division, print_function
 
 import operator
 import os
 import re
-import sys
 import warnings
-
-from six import StringIO
-
-if sys.version_info < (3,):
-    from itertools import izip_longest as zip_longest
-else:
-    from itertools import zip_longest
+from io import StringIO
+from itertools import zip_longest
 
 from lark import Lark, Tree, Visitor
 from particle import Particle
@@ -60,10 +52,6 @@ from .. import data
 from ..utils import charge_conjugate_name
 from .enums import PhotosEnum
 
-# New in Python 3
-if sys.version_info < (3,):
-    FileNotFoundError = IOError
-
 
 class DecFileNotParsed(RuntimeError):
     pass
@@ -73,7 +61,7 @@ class DecayNotFound(RuntimeError):
     pass
 
 
-class DecFileParser(object):
+class DecFileParser:
     """
     The class to parse a .dec decay file.
 
@@ -114,9 +102,9 @@ class DecFileParser(object):
             for filename in self._dec_file_names:
                 # Check input file
                 if not os.path.exists(filename):
-                    raise FileNotFoundError("'{}'!".format(filename))
+                    raise FileNotFoundError(f"'{filename}'!")
 
-                with open(filename, "r") as file:
+                with open(filename) as file:
                     for line in file:
                         # We need to strip the unicode byte ordering if present before checking for *
                         beg = line.lstrip("\ufeff").lstrip()
@@ -271,13 +259,14 @@ class DecFileParser(object):
 
         if filename is None:
             filename = "decfile.lark"
-            with data.open_text(data, filename) as f:
+            with data.basepath.joinpath(filename).open() as f:
                 self._grammar = f.read()
         else:
             # Conversion to handle pathlib on Python < 3.6:
             filename = str(filename)
 
-            self._grammar = open(filename).read()
+            with open(filename) as f:
+                self._grammar = f.read()
 
         self._grammar_info = dict(
             lark_file=filename, parser=parser, lexer=lexer, **options
@@ -738,7 +727,7 @@ All but the first occurrence will be discarded/removed ...""".format(
             if print_model:
                 line = "  {:.4f}   {}     {}  {}".format(bf / norm, *info)
             else:
-                line = "  {:.4f}   {}".format(bf / norm, info[0])
+                line = f"  {bf / norm:.4f}   {info[0]}"
             print(line.rstrip() + ";")
 
     @staticmethod
@@ -761,7 +750,7 @@ All but the first occurrence will be discarded/removed ...""".format(
             elif align_mode == "right":
                 return [s.rjust(max_len) for s in to_align]
             else:
-                raise ValueError("Unknown align mode: {}".format(align_mode))
+                raise ValueError(f"Unknown align mode: {align_mode}")
 
         aligned = []
         for cat in zip_longest(*to_align, fillvalue=""):
@@ -772,7 +761,7 @@ All but the first occurrence will be discarded/removed ...""".format(
             elif align_mode == "right":
                 row = [s.rjust(max_len) for s in cat]
             else:
-                raise ValueError("Unknown align mode: {}".format(align_mode))
+                raise ValueError(f"Unknown align mode: {align_mode}")
 
             aligned.append(row)
 
@@ -1029,10 +1018,10 @@ def get_branching_fraction(decay_mode):
     # and tree.children[0].children[0].value is the BF stored as a str
     try:  # the branching fraction value as a float
         return float(decay_mode.children[0].children[0].value)
-    except RuntimeError:
+    except RuntimeError as e:
         raise RuntimeError(
             "'decayline' Tree does not seem to have the usual structure. Check it."
-        )
+        ) from e
 
 
 def get_final_state_particles(decay_mode):
