@@ -1,5 +1,8 @@
-# -*- coding: utf-8 -*-
 from .decay import DaughtersDict, DecayChain, DecayMode
 from .viewer import DecayChainViewer
 
 __all__ = ("DaughtersDict", "DecayMode", "DecayChain", "DecayChainViewer")
+
+
+def __dir__():
+    return __all__
